==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/examples/src/test/java/org/apache/ignite/examples/MemcacheRestExamplesSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.examples;

//import org.apache.ignite.examples.misc.client.memcache.*;

import org.apache.ignite.testframework.junits.common.GridAbstractExamplesTest;

/**
 * MemcacheRestExample self test.
 */
public class MemcacheRestExamplesSelfTest extends GridAbstractExamplesTest {
//    TODO: IGNITE-711 next example(s) should be implemented for java 8
//    or testing method(s) should be removed if example(s) does not applicable for java 8.
//    /**
//     * @throws Exception If failed.
//     */
//    @Override protected void beforeTest() throws Exception {
//        // Start up a cluster node.
//        startGrid("memcache-rest-examples", MemcacheRestExampleNodeStartup.configuration());
//    }
//
//    /**
//     * @throws Exception If failed.
//     */
//    public void testMemcacheRestExample() throws Exception {
//        MemcacheRestExample.main(EMPTY_ARGS);
//    }
}

==> apache-ignite-2.17.0-src.zip: apache-ignite-2.17.0-src/examples/src/test/java/org/apache/ignite/examples/MemcacheRestExamplesSelfTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.examples;

import org.apache.ignite.examples.misc.client.memcache.MemcacheRestExample;
import org.apache.ignite.examples.misc.client.memcache.MemcacheRestExampleNodeStartup;
import org.apache.ignite.testframework.junits.common.GridAbstractExamplesTest;
import org.junit.Test;

/**
 * MemcacheRestExample self test.
 */
public class MemcacheRestExamplesSelfTest extends GridAbstractExamplesTest {
    /**
     * @throws Exception If failed.
     */
    @Override protected void beforeTest() throws Exception {
        // Start up a cluster node.
        startGrid("memcache-rest-examples", MemcacheRestExampleNodeStartup.configuration());
    }

    /**
     * @throws Exception If failed.
     */
    @Test
    public void testMemcacheRestExample() throws Exception {
        MemcacheRestExample.main(EMPTY_ARGS);
    }
}
